@@ -6,6 +6,16 @@ EXCEPTIONS = {
     "tag:stsci.edu:asdf/asdf-schema-1.0.0",
     "asdf://asdf-format.org/core/manifests/:schema_root: ../../resources/manifests",
     "asdf://asdf-format.org/core/manifests/:standard_prefix: asdf-format.org/core",
+    "http://stsci.edu/schemas/asdf/core/column-1.0.0",
+    "http://stsci.edu/schemas/asdf/core/table-1.0.0",
+    "http://stsci.edu/schemas/asdf/core/subclass_metadata-1.0.0",
+    "http://stsci.edu/schemas/asdf/fits/fits-1.1.0",
+    "http://stsci.edu/schemas/asdf/table/column-1.1.0",
+    "http://stsci.edu/schemas/asdf/table/table-1.1.0",
+    "http://stsci.edu/schemas/asdf/time/time-1.2.0",
+    "http://stsci.edu/schemas/asdf/unit/defunit-1.0.0",
+    "http://stsci.edu/schemas/asdf/unit/quantity-1.2.0",
+    "http://stsci.edu/schemas/asdf/unit/unit-1.0.0",
 }
 
 
@@ -65,6 +75,6 @@ def test_docs_schema_links(
 
     counter = collections.Counter(docs_schema_ids)
     if max(counter.values()) > 1:
-        remove_list = "\n".join(sorted([tag for tag, count in counter.items() if count > 1]))
+        remove_list = "\n".join(sorted(tag for tag, count in counter.items() if count > 1))
         message = "The documentation contains duplicate links to the following schemas: \n" f"{remove_list}"
         assert False, message
